==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/JobManagementEJB/src/com/clustercontrol/jobmanagement/factory/OperateMaintenanceOfJob.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.factory;

import java.util.Date;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.bean.StatusConstant;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobPK;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodePK;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeUtil;

/**
 * ƽ饹
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class OperateMaintenanceOfJob extends OperationJob {
	protected static Log m_log = LogFactory.getLog( OperateMaintenanceOfJob.class );
	
	public OperateMaintenanceOfJob(){
		super();
	}
	
	/**
	 * ֶλ[]
	 * 
	 * @param sessionId
	 * @param jobId
	 * @param facilityId
	 * @throws FinderException
	 * @throws NamingException
	 * @throws RemoveException
	 * @throws CreateException
	 */
	public void maintenanceJob(
			String sessionId, 
			String jobId, 
			String facilityId, 
			Integer endValue) throws FinderException, NamingException {
		
		m_log.debug("maintenanceJob() : sessionId=" + sessionId + ", jobId=" + jobId + ", facilityId=" + facilityId + ", endValue=" + endValue);
		
		if(facilityId != null && facilityId.length() > 0){
			//Ρɤξ
			
			//åIDȥID顢å󥸥֤
			JobSessionNodeLocal sessionNode = 
				JobSessionNodeUtil.getLocalHome().findByPrimaryKey(
						new JobSessionNodePK(sessionId, jobId, facilityId));
			
			if(sessionNode != null){
				//ơλˤ
				sessionNode.setStatus(new Integer(StatusConstant.TYPE_MODIFIED));
				//λͤ
				sessionNode.setEnd_value(endValue);
				//λ
				sessionNode.setEnd_date(new Date());
				sessionNode = null;
				
				//åIDȥID顢å󥸥֤
				JobSessionJobLocal sessionJob = 
					JobSessionJobUtil.getLocalHome().findByPrimaryKey(
							new JobSessionJobPK(sessionId, jobId));
				
				//ֽλå
				if(checkJobEnd(sessionJob)){
					//ֽλξ
					sessionJob =null;
					
					//λ֤
					Integer endStatus = checkEndStatus(sessionId, jobId);
					
					//ơλ֡λ͡λ
					setEndStaus(sessionId, jobId, 
							new Integer(StatusConstant.TYPE_END), endStatus, null);
					
					//ν
					new Notice().notify(sessionId, jobId, endStatus);
					
					//ֽλϢ
					endJob(sessionId, jobId);
				}
			}
		}
		else{
			//Ρɰʳξ
			
			//åIDȥID顢å󥸥֤
			JobSessionJobLocal sessionJob = 
				JobSessionJobUtil.getLocalHome().findByPrimaryKey(
						new JobSessionJobPK(sessionId, jobId));
			
			if(sessionJob != null){
				//ơλˤ
				sessionJob.setStatus(new Integer(StatusConstant.TYPE_MODIFIED));
				//λ֤
				sessionJob.setEnd_status(null);
				//λͤ
				sessionJob.setEnd_value(endValue);
				//λ
				sessionJob.setEnd_date(new Date());
				sessionJob = null;
				
				//ֽλϢ
				endJob(sessionId, jobId);
			}
		}
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/JobManagementEJB/src/com/clustercontrol/jobmanagement/factory/OperateMaintenanceOfJob.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.factory;

import java.util.Date;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.bean.StatusConstant;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobPK;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodePK;
import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeUtil;

/**
 * ジョブ操作の停止[終了値の変更]を行うクラスです。
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class OperateMaintenanceOfJob extends OperationJob {
	/** ログ出力のインスタンス */
	protected static Log m_log = LogFactory.getLog( OperateMaintenanceOfJob.class );
	
	/**
	 * コンストラクタ
	 */
	public OperateMaintenanceOfJob(){
		super();
	}
	
	/**
	 * ジョブを停止[終了値の変更]します。
	 * 
	 * @param sessionId セッションID
	 * @param jobId ジョブID
	 * @param facilityId ファシリティID
	 * @param endValue 終了値
	 * @throws FinderException
	 * @throws NamingException
	 * 
	 * @see com.clustercontrol.jobmanagement.factory.OperationJob#checkJobEnd(JobSessionJobLocal)
	 * @see com.clustercontrol.jobmanagement.factory.OperationJob#checkEndStatus(String, String)
	 * @see com.clustercontrol.jobmanagement.factory.OperationJob#setEndStaus(String, String, Integer, Integer, String)
	 * @see com.clustercontrol.jobmanagement.factory.OperationJob#endJob(String, String)
	 * @see com.clustercontrol.jobmanagement.factory.Notice#notify(String, String, Integer)
	 */
	public void maintenanceJob(
			String sessionId, 
			String jobId, 
			String facilityId, 
			Integer endValue) throws FinderException, NamingException {
		
		m_log.debug("maintenanceJob() : sessionId=" + sessionId + ", jobId=" + jobId + ", facilityId=" + facilityId + ", endValue=" + endValue);
		
		if(facilityId != null && facilityId.length() > 0){
			//ノードの場合
			
			//セッションIDとジョブIDから、セッションジョブを取得
			JobSessionNodeLocal sessionNode = 
				JobSessionNodeUtil.getLocalHome().findByPrimaryKey(
						new JobSessionNodePK(sessionId, jobId, facilityId));
			
			if(sessionNode != null){
				//ステータスを強制終了にする
				sessionNode.setStatus(new Integer(StatusConstant.TYPE_MODIFIED));
				//終了値を設定
				sessionNode.setEnd_value(endValue);
				//終了日時を設定
				sessionNode.setEnd_date(new Date());
				sessionNode = null;
				
				//セッションIDとジョブIDから、セッションジョブを取得
				JobSessionJobLocal sessionJob = 
					JobSessionJobUtil.getLocalHome().findByPrimaryKey(
							new JobSessionJobPK(sessionId, jobId));
				
				//ジョブ終了チェック
				if(checkJobEnd(sessionJob)){
					//ジョブ終了の場合
					sessionJob =null;
					
					//終了状態を取得
					Integer endStatus = checkEndStatus(sessionId, jobId);
					
					//ステータス、終了状態、終了値、終了日時を設定
					setEndStaus(sessionId, jobId, 
							new Integer(StatusConstant.TYPE_END), endStatus, null);
					
					//通知処理
					new Notice().notify(sessionId, jobId, endStatus);
					
					//ジョブ終了時関連処理
					endJob(sessionId, jobId);
				}
			}
		}
		else{
			//ノード以外の場合
			
			//セッションIDとジョブIDから、セッションジョブを取得
			JobSessionJobLocal sessionJob = 
				JobSessionJobUtil.getLocalHome().findByPrimaryKey(
						new JobSessionJobPK(sessionId, jobId));
			
			if(sessionJob != null){
				//ステータスを強制終了にする
				sessionJob.setStatus(new Integer(StatusConstant.TYPE_MODIFIED));
				//終了状態を設定
				sessionJob.setEnd_status(null);
				//終了値を設定
				sessionJob.setEnd_value(endValue);
				//終了日時を設定
				sessionJob.setEnd_date(new Date());
				sessionJob = null;
				
				//ジョブ終了時関連処理
				endJob(sessionId, jobId);
			}
		}
	}
}
